@@ -47,7 +47,7 @@ use Perl::Critic::Utils 1.104 qw{ :characters :severities :data_conversion :clas
 
 use vars qw{$VERSION @ISA @EXPORT_OK %CHECKS %MATCHES};
 BEGIN {
-	$VERSION = '1.21';
+	$VERSION = '1.22';
 
 	# Export the PMV convenience constant
 	@ISA       = 'Exporter';
@@ -80,6 +80,7 @@ BEGIN {
 		_any_CHECK_blocks     => version->new('5.006'),
 		_three_argument_open  => version->new('5.006'),
 		_weaken               => version->new('5.006'),
+		_mkdir_1_arg          => version->new('5.006'),
 
 		_any_qr_tokens        => version->new('5.005.03'),
 		_perl_5005_pragmas    => version->new('5.005'),
@@ -88,6 +89,7 @@ BEGIN {
 		_any_quotelike_regexp => version->new('5.005'),
 		_any_INIT_blocks      => version->new('5.005'),
 		_substr_4_arg         => version->new('5.005'),
+		_splice_negative_length => version->new('5.005'),
 
 		_postfix_foreach      => version->new('5.004.05'),
 	);
@@ -685,7 +687,7 @@ sub _three_argument_open {
 	shift->Document->find_any( sub {
 		$_[1]->isa('PPI::Statement')  or return '';
 		my @children=$_[1]->children;
-		@children >= 7                or return '';
+		#@children >= 7                or return '';
 		my $main_element=$children[0];
 		$main_element->isa('PPI::Token::Word') or return '';
 		$main_element->content eq 'open'       or return '';
@@ -704,6 +706,11 @@ sub _substr_4_arg {
 		my $main_element=$_[1];
 		$main_element->isa('PPI::Token::Word') or return '';
 		$main_element->content eq 'substr'       or return '';
+		return '' if is_hash_key($main_element);
+		return '' if is_method_call($main_element);
+		return '' if is_subroutine_name($main_element);
+		return '' if is_included_module_name($main_element);
+		return '' if is_package_declaration($main_element);
 		my @arguments = parse_arg_list($main_element);
 		if ( scalar @arguments > 3 ) {
 			return 1;
@@ -712,6 +719,55 @@ sub _substr_4_arg {
 	} );
 }
 
+sub _mkdir_1_arg {
+	shift->Document->find_any( sub {
+		my $main_element=$_[1];
+		$main_element->isa('PPI::Token::Word') or return '';
+		$main_element->content eq 'mkdir'       or return '';
+		return '' if is_hash_key($main_element);
+		return '' if is_method_call($main_element);
+		return '' if is_subroutine_name($main_element);
+		return '' if is_included_module_name($main_element);
+		return '' if is_package_declaration($main_element);
+		my @arguments = parse_arg_list($main_element);
+		if ( scalar @arguments != 2 ) {
+			return 1;
+		}
+		return '';
+	} );
+}
+
+sub _splice_negative_length {
+	shift->Document->find_any( sub {
+		my $main_element=$_[1];
+		$main_element->isa('PPI::Token::Word') or return '';
+		$main_element->content eq 'splice'       or return '';
+		return '' if is_hash_key($main_element);
+		return '' if is_method_call($main_element);
+		return '' if is_subroutine_name($main_element);
+		return '' if is_included_module_name($main_element);
+		return '' if is_package_declaration($main_element);
+
+		my @arguments = parse_arg_list($main_element);
+		if ( scalar @arguments < 3 ) {
+			return '';
+		}
+		my $arg=$arguments[2];
+		if (ref($arg) eq 'ARRAY') {
+		  $arg=$arg->[0];
+		}
+		if ($arg->isa('PPI::Token::Number')) {
+			if ($arg->literal<0) {
+				return 1;
+			} else {
+				return '';
+			}
+		}
+		return '';
+	} );
+
+}
+
 sub _postfix_foreach {
 	shift->Document->find_any( sub {
 		my $main_element=$_[1];
